==> org.eclipse.jdt.core.source_3.10.2.v_OTDT_r232_201502011533.jar: org/eclipse/jdt/internal/compiler/problem/ProblemSeverities.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2014 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Technical University Berlin - extended API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.compiler.problem;

public interface ProblemSeverities {

	final int Warning = 0; // during handling only

	final int Error = 1; // when bit is set: problem is error, if not it is a warning
	final int AbortCompilation = 2;
	final int AbortCompilationUnit = 4;
	final int AbortType = 8;
	final int AbortMethod = 16;
	final int Abort = 30; // 2r11110
	final int Optional = 32; // when bit is set: problem was configurable
	final int SecondaryError = 64;
	final int Fatal = 128; // when bit is set: problem was either a mandatory error, or an optional+treatOptionalErrorAsFatal
	final int Ignore = 256; // during handling only
	final int InternalError = 512;  // always exposed, even when silent error handling policy is in effect.

//{ObjectTeams: signal problem that should be ignored, but yet recorded to match potential @SuppressWarnings
	final int IgnoredGenerated = 1024;
// SH}
}

==> org.eclipse.jdt.core.source_3.12.0.v_OTDT_r250_201606070956.jar: org/eclipse/jdt/internal/compiler/problem/ProblemSeverities.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2016 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Technical University Berlin - extended API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.compiler.problem;

public interface ProblemSeverities {

	final int Warning = 0; // during handling only

	final int Error = 1; // when bit is set: problem is error, if not it is a warning
	final int AbortCompilation = 2;
	final int AbortCompilationUnit = 4;
	final int AbortType = 8;
	final int AbortMethod = 16;
	final int Abort = 30; // 2r11110
	final int Optional = 32; // when bit is set: problem was configurable
	final int SecondaryError = 64;
	final int Fatal = 128; // when bit is set: problem was either a mandatory error, or an optional+treatOptionalErrorAsFatal
	final int Ignore = 256; // during handling only
	final int InternalError = 512;  // always exposed, even when silent error handling policy is in effect.
	final int Info = 1024; // When bit is set, the unit or project is not flagged.

//{ObjectTeams: signal problem that should be ignored, but yet recorded to match potential @SuppressWarnings
	final int IgnoredGenerated = 2048;
// SH}

	final int CoreSeverityMASK = Warning | Error | Info | Ignore;
}
